#version unofficial MegaPov 0.4;

#include "enter"
#include "metrics.inc"

#declare HighQuality = on ;

#include "machtext.inc"
#include "gauges.inc"

global_settings {
  assumed_gamma 1
  #if (HighQuality)
    max_trace_level 7
  #else
    max_trace_level 6
  #end
  
  #if (HighQuality)
    ini_option "+QR"
    radiosity {
      pretrace_start 0.08
      pretrace_end   0.01
      count 100
      nearest_count 10
      error_bound 0.5
      recursion_limit 2
      media on
      normal on
      always_sample no
      load_file "radiosity.dat"
    }
  #end
}

camera {
  location -9.9*m*z+(1.7+1)*m*y
  look_at  (1+1)*m*y
  angle 40
}
#if (!HighQuality)
  light_source {
    -9*m*z+(1.7+1)*m*y
    color rgb 0.4
    shadowless
  }
#end

difference {						    // room
  cylinder { 0, 5*m*y, 10*m inverse }
  box { <-75*cm, 1*m, -9*m>, <75*cm, 3*m, -12*m> }
  box { <-75*cm, 1*m, -9*m>, <75*cm, 3*m, -12*m> rotate 120*y }
  box { <-75*cm, 1*m, -9*m>, <75*cm, 3*m, -12*m> rotate -120*y }
  texture { TConcrete scale 2.52*m }
}

union {							    // center element
  difference {
    union {
      difference {					    // bottom
	cone { -1*cm*y, 2*m, 1*m*y, 1.5*m }
	sphere { 0, 1.4*m scale <1, 0.25, 1> translate 1*m*y }
	bounded_by { box { <-2*m, -1*cm, -2*m>, <2*m, 1*m, 2*m> }  }
      }
      #declare i = 3.6/2 ;
      union {
	#while (i<90)
	  cone { <2*m, -1*cm, 0>, 12.6*cm, <1.5*m, 1*m, 0>, 9.4*cm rotate i*y }
	  #declare i = i + 3.6 ;
	#end
	bounded_by { box { <0, -1*cm, -2.1*m>, <2.1*m, 1*m, 0> } }
      }
      union {
	#while (i<180)
	  cone { <2*m, -1*cm, 0>, 12.6*cm, <1.5*m, 1*m, 0>, 9.4*cm rotate i*y }
	  #declare i = i + 3.6 ;
	#end
	bounded_by { box { <0, -1*cm, -2.1*m>, <-2.1*m, 1*m, 0> } }
      }
      union {
	#while (i<270)
	  cone { <2*m, -1*cm, 0>, 12.6*cm, <1.5*m, 1*m, 0>, 9.4*cm rotate i*y }
	  #declare i = i + 3.6 ;
	#end
	bounded_by { box { <0, -1*cm, 2.1*m>, <-2.1*m, 1*m, 0> } }
      }
      union {
	#while (i<360)
	  cone { <2*m, -1*cm, 0>, 12.6*cm, <1.5*m, 1*m, 0>, 9.4*cm rotate i*y }
	  #declare i = i + 3.6 ;
	#end
	bounded_by { box { <0, -1*cm, 2.1*m>, <2.1*m, 1*m, 0> } }
      }
    }
    union {
      cylinder { <0, 50*cm, 1*cm>, <0, 50*cm, -2*m>, 19.9*cm }
      cylinder { <45*cm, 50*cm, 1*cm>, <45*cm, 50*cm, -2*m>, 19.9*cm }
      cylinder { <-45*cm, 50*cm, 1*cm>, <-45*cm, 50*cm, -2*m>, 19.9*cm }
      rotate 60*y
    }
    union {
      cylinder { <0, 50*cm, 1*cm>, <0, 50*cm, -2*m>, 19.9*cm }
      cylinder { <45*cm, 50*cm, 1*cm>, <45*cm, 50*cm, -2*m>, 19.9*cm }
      cylinder { <-45*cm, 50*cm, 1*cm>, <-45*cm, 50*cm, -2*m>, 19.9*cm }
      rotate -60*y
    }
    union {
      cylinder { <0, 50*cm, 1*cm>, <0, 50*cm, -2*m>, 19.9*cm }
      cylinder { <45*cm, 50*cm, 1*cm>, <45*cm, 50*cm, -2*m>, 19.9*cm }
      cylinder { <-45*cm, 50*cm, 1*cm>, <-45*cm, 50*cm, -2*m>, 19.9*cm }
      rotate 180*y
    }
    bounded_by { box { <-2.1*m, -1*cm, -2.1*m>, <2.1*m, 1*m, 2.1*m> } }
  }
  torus { 1.55*m, 10*cm translate 95*cm*y }
  union {						    // top
    difference {
      cone { 5.01*m*y, 2*m, 4*m*y, 1.5*m }
      sphere { 0, 1.4*m scale <1, 0.25, 1> translate 4*m*y }
      bounded_by { box { <-2*m, 5.01*m, -2*m>, <2*m, 4*m, 2*m> } }
    }
    #declare i = 0 ;
    union {
      #while (i<90)
	cone { <2*m, 5.01*m, 0>, 12.6*cm, <1.5*m, 4*m, 0>, 9.4*cm rotate i*y }
	#declare i = i + 3.6 ;
      #end
      bounded_by { box { <0, 4*m, -2.1*m>, <2.1*m, 5*m, 0> } }
    }
    union {
      #while (i<180)
	cone { <2*m, 5.01*m, 0>, 12.6*cm, <1.5*m, 4*m, 0>, 9.4*cm rotate i*y }
	#declare i = i + 3.6 ;
      #end
      bounded_by { box { <0, 4*m, -2.1*m>, <-2.1*m, 5*m, 0> } }
    }
    union {
      #while (i<270)
	cone { <2*m, 5.01*m, 0>, 12.6*cm, <1.5*m, 4*m, 0>, 9.4*cm rotate i*y }
	#declare i = i + 3.6 ;
      #end
      bounded_by { box { <0, 4*m, 2.1*m>, <-2.1*m, 5*m, 0> } }
    }
    union {
      #while (i<360)
	cone { <2*m, 5.01*m, 0>, 12.6*cm, <1.5*m, 4*m, 0>, 9.4*cm rotate i*y }
	#declare i = i + 3.6 ;
      #end
      bounded_by { box { <0, 4*m, 2.1*m>, <2.1*m, 5*m, 0> } }
    }
    torus { 1.55*m, 10*cm translate 405*cm*y }
  }
  texture { TMetal }
  texture { Scarring scale 10*cm }
  texture { Chipping2 scale 1*cm }
  texture { Rusting2 scale 10*cm }
  texture { Rusting scale 5*cm }
  texture { Dirt scale 10*cm }
  //pigment { rgb 1 }
}

difference {						    // glass tube
  cylinder { -1*m*y, 6*m*y, 1.45*m }
  cylinder { -2*m*y, 7*m*y, 1.40*m }
  material { MGlass }
}

cylinder {						    // media
  1*cm*y, 4.99*m*y, 1.401*m
  pigment { rgbf 1 }
  hollow
  interior {
    media {
      emission 0.1
      emission_type 2
      emission_extinction 2
      method 3
      intervals 1
      samples 5, 5
      density {
	cylindrical 
	color_map {
	  [ 0.0 color rgb <0.0, 0.0, 0.0> ]
	  [ 0.1 color rgb <1.0, 0.1, 0.0> ]
	  [ 0.7 color rgb <1.0, 0.5, 0.1> ]
	  [ 1.0 color rgb <1.0, 1.0, 1.0> ]
	}
	turbulence 0.05
	octaves 4
	
	scale 1.39*m
      }
    }
  }
}

#declare i = 0;						    // wall lamps
#while (i<360)
  union {
    light_source {
      -1.5*cm*x, rgb 20
      looks_like { 
	sphere {
	  1.5*cm*x, 15*cm scale <0.2, 1, 1>
	}
	pigment { rgb 1 }
	finish { ambient 1 }
      }
      fade_distance 15*cm
      fade_power 2
    }
    cylinder { 
      14.9*cm*y, 2*m*y, 2*mm translate -2*mm*x
    }
    torus {
      15*cm, 5*mm
      rotate 90*z
    }
    translate <10, 3.5, 0>*m
    rotate i*y
    texture { pigment { color rgb 1 } }
  }
  #declare i = i+30 ;
#end

#macro Tube (C)						    // energy tubes
  difference {
    cylinder { <0, 50*cm, 0>, <0, 50*cm, -11*m>, 20*cm }
    cylinder { <0, 50*cm, 1*cm>, <0, 50*cm, -11.1*m>, 18*cm }
    material { MGlass }
  }
  cylinder {
    <0, 50*cm, 1*cm>, <0, 50*cm, -11.1*m>, 18.1*cm
    pigment { rgbf 1 }
    hollow
    interior {
      media {
	emission 1
	emission_type 2
	emission_extinction 2
	method 3
	intervals 1
	samples 5, 5
	density {
	  cylindrical
	  color_map {
	    [ 0.0 color rgb <0.0, 0.0, 0.0> ]
	    [ 0.1 color rgb C ]
	    [ 0.7 color rgb <1.0, 0.5, 0.1> ]
	    [ 1.0 color rgb <1.0, 1.0, 1.0> ]
	  }
	  turbulence 0.05
	  octaves 4
	  scale 17.5*cm
	  rotate 90*x
	  translate 50*cm*y
	}
      }
    }
  }
  #local i = 140*cm ;
  #while (i<11.1*m)
    torus {
      19*cm, 3*cm
      rotate 90*x
      translate <0, 50*cm, -i>
      texture { TMetal }
      texture { Scarring scale 10*cm }
      texture { Chipping2 scale 1*cm }
      texture { Rusting2 scale 10*cm }
      texture { Rusting scale 5*cm }
      texture { Dirt scale 10*cm }
    }
    #local i = i + 40*cm ;
  #end
#end
#declare Ramp = union {					    // ramps
  difference {
    box { <-50*cm, -1*m, -11*m>, <50*cm, 50*cm, 0> }
    cylinder { <0, 50*cm, 1*cm>, <0, 50*cm, -11.1*m>, 19.9*cm }
    cylinder { <45*cm, 50*cm, 1*cm>, <45*cm, 50*cm, -11.1*m>, 19.9*cm }
    cylinder { <-45*cm, 50*cm, 1*cm>, <-45*cm, 50*cm, -11.1*m>, 19.9*cm }
    texture { TMetal } 
    texture { Scarring scale 10*cm }
    texture { Chipping2 scale 1*cm }
    texture { Rusting2 scale 10*cm }
    texture { Rusting scale 5*cm }
    texture { Dirt scale 10*cm }
  }
  union { Tube (<1, 0, 0>) translate  45*cm*x }
  union { Tube (<0, 1, 0>) }
  union { Tube (<0, 0, 1>) translate -45*cm*x }
}
union {
  object { Ramp rotate  60*y }
  object { Ramp rotate -60*y }
  object { Ramp rotate 180*y }
}

							    // Control boards
difference {
  cylinder { -1*cm*y, 3*m*y, 9*m }
  cylinder { -2*cm*y, 3.1*m*y, 3*m }
  box { <-2*m, -2*cm, -10*m>, <2*m, 3.1*m, 10*m> }
  box { <-2*m, -2*cm, -10*m>, <2*m, 3.1*m, 10*m> rotate 120*y }
  box { <-2*m, -2*cm, -10*m>, <2*m, 3.1*m, 10*m> rotate -120*y }
  MetalTexture()
}
#declare Panel = union {
  box { <-44.5*cm, -42.5*cm, 3*mm>, <44.5*cm, 42.5*cm, -3*mm> }
  box { <-42.5*cm, -44.5*cm, 3*mm>, <42.5*cm, 44.5*cm, -3*mm> }
  cylinder { <-42.5*cm, -42.5*cm, 3*mm>, <-42.5*cm, -42.5*cm, -3*mm>, 2*cm }
  cylinder { <42.5*cm, -42.5*cm, 3*mm>, <42.5*cm, -42.5*cm, -3*mm>, 2*cm }
  cylinder { <-42.5*cm, 42.5*cm, 3*mm>, <-42.5*cm, 42.5*cm, -3*mm>, 2*cm }
  cylinder { <42.5*cm, 42.5*cm, 3*mm>, <42.5*cm, 42.5*cm, -3*mm>, 2*cm }
  
  #local i = -42.5*cm ;
  #while (i < 42.5*cm)
    sphere {
      0, 2*cm
      scale <1, 1, 0.5>
      translate <-42.5*cm, i, -3*mm>
    }
    sphere {
      0, 2*cm
      scale <1, 1, 0.5>
      translate <42.5*cm, -i, -3*mm>
    }
    sphere {
      0, 2*cm
      scale <1, 1, 0.5>
      translate <-i, -42.5*cm, -3*mm>
    }
    sphere {
      0, 2*cm
      scale <1, 1, 0.5>
      translate <i, 42.5*cm, -3*mm>
    }
    #local i = i + (95/11)*cm ;
  #end
}
#local i = -4*m ;
#while (i>-9*m)
  #local j = 0 ;
  #while (j < 3)
    union {
      GaugePanel (5, 5)
      object { 
	Panel
	translate -1.25*m*y
	ChromeTexture()
      }
      rotate -90*y
      translate <-1.99*m, 2.2*m, i>
      rotate 120*y*j
    }
    #local j = j + 1 ;
  #end
  #local i = i - 1*m ;
#end
#declare Panel = union {
  box { <-44.5*cm, -94.5*cm, 3*mm>, <44.5*cm, 94.5*cm, -3*mm> }
  box { <-39.5*cm, -99.5*cm, 3*mm>, <39.5*cm, 99.5*cm, -3*mm> }
  cylinder { <-39.5*cm, -94.5*cm, 3*mm>, <-39.5*cm, -94.5*cm, -3*mm>, 5*cm }
  cylinder { <39.5*cm, -94.5*cm, 3*mm>, <39.5*cm, -94.5*cm, -3*mm>, 5*cm }
  cylinder { <-39.5*cm, 94.5*cm, 3*mm>, <-39.5*cm, 94.5*cm, -3*mm>, 5*cm }
  cylinder { <39.5*cm, 94.5*cm, 3*mm>, <39.5*cm, 94.5*cm, -3*mm>, 5*cm }
  
  #local i = -94.5*cm ;
  #while (i <= 94.5*cm)
    sphere {
      0, 3*cm
      scale <1, 1, 0.5>
      translate <-39.5*cm, i, -3*mm>
    }
    sphere {
      0, 3*cm
      scale <1, 1, 0.5>
      translate <39.5*cm, i, -3*mm>
    }
    #local i = i + 9*cm ;
  #end
  #local i = (79/9-39.5)*cm ;
  #while (i < 39.5*cm)
    sphere {
      0, 3*cm
      scale <1, 1, 0.5>
      translate <i, -94.5*cm, -3*mm>
    }
    sphere {
      0, 3*cm
      scale <1, 1, 0.5>
      translate <i, 94.5*cm, -3*mm>
    }
    #local i = i + 79/9*cm ;
  #end
}
#local i = -4*m ;
#while (i>-9*m)
  object {
    Panel
    ChromeTexture()
    rotate 90*y
    translate <1.998*m, 1.5*m, i>
  }
  object {
    Panel
    ChromeTexture()
    rotate 90*y
    translate <1.998*m, 1.5*m, i>
    rotate -120*y
  }
  object {
    Panel
    ChromeTexture()
    rotate 90*y
    translate <1.998*m, 1.5*m, i>
    rotate 120*y
  }
  #local i = i - 1*m ;
#end

#include "makechain.inc"
#declare Beam = union {
  box { -<2*cm, 5.1*cm, 11*m>, <2*cm, 5.1*cm, -4.89*m> }
  box { <-5*cm, 5*cm, -11*m>, <5*cm, 8*cm, -4.89*m> }
  box { <-5*cm, -5*cm, -11*m>, <5*cm, -8*cm, -4.89*m> }
}
#declare Beam2 = intersection {
  union {
    box { -<2*cm, 7.8*cm, 87*cm>, <2*cm, 7.8*cm, 87*cm> }
    box { <-5*cm, 7.56*cm, -87*cm>, <5*cm, 10*cm, 87*cm> }
    box { <-5*cm, -7.56*cm, -87*cm>, <5*cm, -10*cm, 87*cm> }
    rotate 45*x
    translate 50*cm*y
  }
  box { <-5.1*cm, -1*cm, -60*cm>, <5.1*cm, 94*cm, 60*cm> }
  translate -4.6*m*z
}
#declare Beam3 = union {
  box { -<2*cm, 1*cm, 5.1*cm>, <2*cm, 94*cm, 5.1*cm> }
  box { <-5*cm, -1*cm, -5*cm>, <5*cm, 94*cm, -8*cm> }
  box { <-5*cm, -1*cm, 5*cm>, <5*cm, 94*cm, 8*cm> }
}
#declare Beam4 = intersection {
  union {
    box { -<90, 5.1*cm, 2*cm>, <90, 5.1*cm, 2*cm> }
    box { <-90, -5*cm, -4.9*cm>, <90, -8*cm, 4.9*cm> }
    box { <-90, 5*cm, -4.9*cm>, <90, 8*cm, 4.9*cm> }
    rotate 27*z
    translate 47*cm*y
  }
  box { -<75*cm, 1*cm, 5*cm>, <75*cm, 94*cm, 5*cm> }
}
#declare Foot = union {
  object { Beam3 translate -75*cm*x }
  object { Beam3 translate 75*cm*x }
  object { Beam4 }
  MetalTexture()
}
#declare Step = box {
  -<75*cm, 1*cm, 10*cm>, <75*cm, 1*cm, 10*cm>
}
#declare Plate = union {
  difference {
    box { -<74*cm, 7.5*mm, 61*cm>, <74*cm, 7.5*mm, 61*cm> }
    box { -<70*cm, 8*mm, 57*cm>, <70*cm, 8*mm, 57*cm> }
  }
  #local i = -68*cm ;
  #while (i < 70*cm)
    box { -<1*mm, 7*mm, 60*cm>, <1*mm, 7*mm, 60*cm> translate i*x }
    #local i = i + 2*cm ;
  #end
  #local i = -55*cm ;
  #while (i < 57*cm)
    box { -<71*cm, 7*mm, 1*mm>, <71*cm, 7*mm, 1*mm> translate i*z }
    #local i = i + 2*cm ;
  #end
}
#declare Post = union {
  cylinder { -1*mm*y, 1.05*m*y, 2*cm }
  sphere { 1.05*m*y, 2*cm }
  torus { 2.5*cm, 5*mm translate <0, 99.5*cm, 3*cm> }
  torus { 2.5*cm, 5*mm translate <0, 99.5*cm, -3*cm> }
  ChromeTexture2()
}
#declare Ramp = union {
  object { Post translate -3.90*m*z }
  object { Post translate -5.00*m*z+1*m*y }
  object { Post translate -6.25*m*z+1*m*y }
  object { Post translate -7.50*m*z+1*m*y }
  object { Post translate -8.75*m*z+1*m*y }
  object { Post translate -10.0*m*z+1*m*y }
  
  object { Chain rotate 90*y translate -5.625*m*z+1*m*y }
  object { Chain rotate 90*y translate -6.875*m*z+1*m*y }
  object { Chain rotate 90*y translate -8.125*m*z+1*m*y }
  object { Chain rotate 90*y translate -9.375*m*z+1*m*y }
  
  object { Chain2 rotate -90*y translate -4.5*m*z+1*m*y }
}
#declare Sidewalk = union {
  object { Beam translate -75*cm*x+1*m*y }
  object { Beam translate 75*cm*x+1*m*y }
  object { Beam2 translate -75*cm*x }
  object { Beam2 translate 75*cm*x }

  object { Plate translate -5.625*m*z+95.75*cm*y }
  object { Plate translate -6.875*m*z+95.75*cm*y }
  object { Plate translate -8.125*m*z+95.75*cm*y }
  object { Plate translate -9.375*m*z+95.75*cm*y }

  object { Foot translate -5.4*m*z }
  object { Foot scale <-1, 1, 1> translate -6.25*m*z }
  object { Foot translate -7.5*m*z }
  object { Foot scale <-1, 1, 1> translate -8.75*m*z }

  object { Ramp translate -75*cm*x }
  object { Ramp translate 75*cm*x }
  
  object { Step translate -490*cm*z+80*cm*y }
  object { Step translate -470*cm*z+60*cm*y }
  object { Step translate -450*cm*z+40*cm*y }
  object { Step translate -430*cm*z+20*cm*y }
  
  MetalTexture()
}
/*box {
  <-1, -1, -11>*m, <1, 1, -4>*m
  pigment { color rgb 1 }
}*/

							    // plateformes
object { Sidewalk }
object { Sidewalk rotate 120*y }
object { Sidewalk rotate -120*y }

#declare Door = union {
  box { <-80*cm, 95*cm, -10.5*m>, <80*cm, 3.1*m, -10.6*m> }
  cylinder { 
    <0, 95*cm, 0>, <0, 3.1*m, 0>, 2*cm 
    scale <1.0, 1.0, 0.5>
    translate -10.5*m*z
  }
  ChromeTexture()
}
object { Door }
object { Door rotate 120*y }
object { Door rotate -120*y }

#include "leave"
